/**
 * Copyright (C) 2019-2021 Carl Kittelberger <icedream@icedream.pw>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import { selectUnit } from '@formatjs/intl-utils';
import React from 'react';
import { useIntl } from 'react-intl';
import { FormattedRelativeTime } from './localization';

export default function RelativeTime({
  children: dateTimeValue,
}: {
  children: Date,
}) {
  const intl = useIntl();
  const { value, unit } = selectUnit(dateTimeValue, new Date());
  const title = `${intl.formatDate(dateTimeValue)} ${intl.formatTime(dateTimeValue)}`;
  return (
    <time title={title} dateTime={dateTimeValue.toISOString()}>
      <FormattedRelativeTime
        value={value}
        unit={unit}
      />
    </time>
  );
}
